@@ -18,14 +18,13 @@
 
 */
 
-/* $Header: /repository/projects/libjsonevt/utf8.h,v 1.2 2009-02-23 17:46:55 don Exp $ */
-
+/* $Revision: 1568 $ */
 #ifndef UTF8_H
 #define UTF8_H
 
-#include "uni.h"
+#include <uni.h>
 
-#include "int_defs.h"
+#include <int_defs.h>
 
 UNI_DO_CPLUSPLUS_WRAP_BEGIN
 
